@@ -1,7 +1,7 @@
 estambi <-
 function(mat, matsd, equalsign){
    if(equalsign!=TRUE){
-     mat <- matrix(rnorm(length(mat), mean=mat, sd=matsd),nr=dim(mat)[1], nc=dim(mat)[2])
+     mat <- matrix(rnorm(length(mat), mean=mat, sd=matsd),nrow=dim(mat)[1], ncol=dim(mat)[2])
     }
    if(equalsign==TRUE){
      mat <- mat + (matsd*rnorm(1,mean=0,sd=1))
